@@ -1,21 +1,22 @@
-from backy.timeout import TimeOut, TimeOutError
 import pytest
 
+from backy.timeout import TimeOut, TimeOutError
+
 
 def test_timeout(capsys):
-    timeout = TimeOut(.05, .01)
+    timeout = TimeOut(0.05, 0.01)
     while timeout.tick():
-        print('tick')
+        print("tick")
     assert timeout.timed_out
     out, err = capsys.readouterr()
-    assert 'tick\ntick\ntick' in out
+    assert "tick\ntick\ntick" in out
 
 
 def test_raise_on_timeout(capsys):
-    timeout = TimeOut(.05, .01, raise_on_timeout=True)
+    timeout = TimeOut(0.05, 0.01, raise_on_timeout=True)
     with pytest.raises(TimeOutError):
         while True:
             timeout.tick()
-            print('tick')
+            print("tick")
     out, err = capsys.readouterr()
-    assert 'tick\ntick\ntick' in out
+    assert "tick\ntick\ntick" in out
